# Software

```{toctree}
:hidden: true

software/cli
software/nodes
software/can
software/msg
```

The OpenHydroponics Python software is designed to manage talk to nodes on the OpenHydroponics network, handle all low
level tasks, and provide a friendlier API to the developer. This framework is an asynchronous framework, read more about setting up an async environment [here](https://docs.python.org/3/library/asyncio.html).

Read more about getting access to the nodes [here](software/nodes).
